aboutsummaryrefslogtreecommitdiff
path: root/engines/sword25/util
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sword25/util')
-rw-r--r--engines/sword25/util/pluto/pluto.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sword25/util/pluto/pluto.cpp b/engines/sword25/util/pluto/pluto.cpp
index 2a39e98719..957f5af795 100644
--- a/engines/sword25/util/pluto/pluto.cpp
+++ b/engines/sword25/util/pluto/pluto.cpp
@@ -626,10 +626,10 @@ static void persist(PersistInfo *pi)
int zero = 0;
// FIXME: Casting a pointer to an integer data type is a bad idea we
// should really get rid of this by fixing the design of this code.
// For now casting to ssize_t should silence most (all?) compilers,
// since ssize_t is supposedly the same size as a pointer on most
// (modern) architectures.
- int ref = (ssize_t)lua_touserdata(pi->L, -1);
+ int ref = (int)(size_t)lua_touserdata(pi->L, -1);
pi->writer(pi->L, &zero, sizeof(int), pi->ud);
pi->writer(pi->L, &ref, sizeof(int), pi->ud);
lua_pop(pi->L, 1);
@@ -626,10 +626,10 @@ static void persist(PersistInfo *pi)
// FIXME: Casting a pointer to an integer data type is a bad idea we
// should really get rid of this by fixing the design of this code.
- // For now casting to ssize_t should silence most (all?) compilers,
- // since ssize_t is supposedly the same size as a pointer on most
+ // For now casting to size_t should silence most (all?) compilers,
+ // since size_t is supposedly the same size as a pointer on most
// (modern) architectures.